@@ -7,7 +7,7 @@ import yaml
 
 from .db import DB
 
-__version__ = "0.3.6"
+__version__ = "0.3.7"
 
 logging.basicConfig(format="%(asctime)s: %(message)s",
                     level=logging.INFO)
@@ -116,7 +116,7 @@ def main():
         ))
 
         try:
-            Sync(cfg, args.session, db.DB(args.data)).sync(args.id)
+            Sync(cfg, args.session, DB(args.data)).sync(args.id)
         except KeyboardInterrupt as e:
             logging.info("sync cancelled manually")
             quit()
@@ -128,7 +128,7 @@ def main():
         from .build import Build
 
         logging.info("building site")
-        b = Build(get_config(args.config), db.DB(args.data))
+        b = Build(get_config(args.config), DB(args.data))
         b.load_template(args.template)
         b.build()
 
